execute_with_retry

Function execute_with_retry 

async fn execute_with_retry(
    client: &mut Client,
    query: &str,
) -> Result<(), Error>
Executes query, retrying transient errors.

NOTE: a retry re-executes query in its entirety. If query contains multiple statements (e.g. with split-lines=false), statements that committed before the transient error are executed again, duplicating their side effects. Callers must pass a single statement, or statements that are safe to re-execute.